managed window rules

Alex Pasadyn ajp at mail.utexas.edu
Wed Feb 4 21:39:14 CST 2004


ChangeLog:
- Make full-screen popup windows managed


This gets me keyboard input in Half-Life and several other games, and 
several troublesome installers are useful outside of desktop mode. 
Hopefully it doesn't break something else.

-ajp

-------------- next part --------------
Index: dlls/x11drv/window.c
===================================================================
RCS file: /home/wine/wine/dlls/x11drv/window.c,v
retrieving revision 1.69
diff -u -r1.69 window.c
--- dlls/x11drv/window.c	21 Jan 2004 02:22:26 -0000	1.69
+++ dlls/x11drv/window.c	5 Feb 2004 02:37:53 -0000
@@ -129,8 +129,13 @@
     if (win->dwStyle & WS_THICKFRAME) return TRUE;
     /* application windows are managed */
     if (win->dwExStyle & WS_EX_APPWINDOW) return TRUE;
-    /* popup windows that aren't owned are managed */
-    if ((win->dwStyle & WS_POPUP) && !win->owner) return TRUE;
+    /* full-screen popup windows are managed */
+    if ((win->dwStyle & WS_POPUP) && 
+        (win->rectWindow.right-win->rectWindow.left) == screen_width && 
+        (win->rectWindow.bottom-win->rectWindow.top) == screen_height) 
+    {
+        return TRUE;
+    }
     /* default: not managed */
     return FALSE;
 }



More information about the wine-patches mailing list